Ancestry - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Ancestry

An ancestry is Betty’s main data model. It organizes all the information in your family history in a way that can easily be used across all parts of Betty. The main components are entities, fields on entities, and associations between entities.

A model with lots of data is a graph, a network, like a web of information that can be traversed, analyzed, expanded, and ultimately generated into a site.

In code, you will be using `betty.ancestry.Ancestry`, through which you can access any entity of any type.

Python

    from betty.ancestry import Ancestry, Person

    ancestry = await Ancestry.new()
    person = Person(id='a1b2')
    ancestry.add(person)
    assert person is ancestry[Person]['a1b2']

Jinja2

    {% set people = ancestry['person'] %}
    {% set person_a1b2 = people['a1b2'] %}

## In this section

- Citation

- Dates

- Enclosure

- Event

- Event Type

- File

- File reference

- Link

- Media Type

- Name

- Note

- Person

- Person Name

- Place

- Presence

- Presence Role

- Privacy

- Source

## See also

- Entity type plugins